==> igniteui-react-layouts-18.7.3.tgz: package/esm5/lib/igr-tool-action-separator.js <==
import { __extends } from "tslib";
import { IgrToolAction } from "./igr-tool-action";
import { ToolActionSeparator } from "./ToolActionSeparator";
import { ensureBool } from "igniteui-react-core";
var IgrToolActionSeparator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrToolActionSeparator, _super);
    function IgrToolActionSeparator(props) {
        return _super.call(this, props) || this;
    }
    IgrToolActionSeparator.prototype.createImplementation = function () {
        return new ToolActionSeparator();
    };
    Object.defineProperty(IgrToolActionSeparator.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionSeparator.prototype, "size", {
        /**
         * Gets or sets the size of the separator.
        */
        get: function () {
            return this.i.hd;
        },
        set: function (v) {
            this.i.hd = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionSeparator.prototype, "isGroupHeaderSeparator", {
        /**
         * Gets or sets whether to use group header styling or regular styling on this separator.
        */
        get: function () {
            return this.i.hb;
        },
        set: function (v) {
            this.i.hb = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    return IgrToolActionSeparator;
}(IgrToolAction));
export { IgrToolActionSeparator };

==> igniteui-react-layouts-18.7.6.tgz: package/esm5/lib/igr-tool-action-separator.js <==
import { __extends } from "tslib";
import { IgrToolAction } from "./igr-tool-action";
import { ToolActionSeparator } from "./ToolActionSeparator";
import { ensureBool } from "igniteui-react-core";
var IgrToolActionSeparator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrToolActionSeparator, _super);
    function IgrToolActionSeparator(props) {
        return _super.call(this, props) || this;
    }
    IgrToolActionSeparator.prototype.createImplementation = function () {
        return new ToolActionSeparator();
    };
    Object.defineProperty(IgrToolActionSeparator.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionSeparator.prototype, "size", {
        /**
         * Gets or sets the size of the separator.
        */
        get: function () {
            return this.i.g9;
        },
        set: function (v) {
            this.i.g9 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionSeparator.prototype, "isGroupHeaderSeparator", {
        /**
         * Gets or sets whether to use group header styling or regular styling on this separator.
        */
        get: function () {
            return this.i.g7;
        },
        set: function (v) {
            this.i.g7 = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    return IgrToolActionSeparator;
}(IgrToolAction));
export { IgrToolActionSeparator };
